% Script to generate matrices of pairwise payoffs by simulating play
% between the various strategies.

clear all


% create a matrix with each of the possible 16 memory-2 states (this is
% used by the calc_pairwise_payoff function)
states=[];
for st1=[1 0]
    for st2=[1 0]
        for st3=[1 0]
            for st4=[1 0]
                states=[states; st1 st2 st3 st4];

            end
        end
    end
end


% define the strategies you wish to use (using the definitions given in
% calc_pairwise_payoff.m 
strats=cell(1);
names=cell(1);
names{1}='ALLC';strats{1}=[1 1 1 1 1 1 1 1 	1 1 1 1 1 1 1 1 ];
names{2}='TFT';strats{2}=[1 0 1 0 1 0 1 0 	1 0 1 0 1 0 1 0 ];
names{3}='TF2T';strats{3}=[1 1 1 1 1 0 1 0 	1 1 1 1 1 0 1 0 ];
names{4}='TF3T';strats{4}=[1 3];
names{5}='2TF2T';strats{5}=[5 1];
names{6}='GRIM';strats{6}=[0.5 1];
names{7}='GRIM2';strats{7}=[0.5 2];
names{8}='GRIM3';strats{8}=[0.5 3];
names{9}='PTFT';strats{9}=[1 0 0 1 1 0 0 1	1 0 0 1 1 0 0 1];
names{10}='2PTFT';strats{10}=[1	0	0	0	0	0	0	0	0	0	0	0	1	0	0	1];
names{11}='2TFT';strats{11}=[1 0 1 0 0 0 0 0 	1 0 1 0 0 0 0 0 ];
names{12}='ALLD';strats{12}=[0 0 0 0 0 0 0 0 	0 0 0 0 0 0 0 0 ];
names{13}='C-to-ALLD';strats{13}=[2 1];
names{14}='D-TFT';strats{14}=[4 1];
names{15}='D-TF2T';strats{15}=[4 2];
names{16}='D-TF3T';strats{16}=[4 2.5];
names{17}='D-Grim2';strats{17}=[4 6];
names{18}='D-Grim3';strats{18}=[4 7];
names{19}='DC-Alt';strats{19}=[4 3];

% define the game parameters
c=2 % cost of cooperation
E=1/8 % error rate
d=7/8 % continuation probability
nRuns=1e4 % number of games to simulate for each pairing
gameLengths=1+geornd(1-d,nRuns,1); % list of game lengths for each game



bidx=1; % keep track of how many b vals youve looked at
payoffs=zeros(length(strats)); % initialize payoff matrix

% now step through each b value, and simulate to get payoffs
for b=[1.5 2 2.5 4]*c
    for i=1:length(strats)
        names{i}
        for j=i:length(strats)
            [p1 p2]=calc_pairwise_payoff(strats{i},strats{j},b,c,E,nRuns,states,gameLengths);

            if i==j
                payoffs(i,i,bidx)=(p1+p2)/2;
            else
                payoffs(i,j,bidx)=p1;
                payoffs(j,i,bidx)=p2;
            end
        end
    end

bidx=bidx+1;
end

'DONE!'
payoffs
